@@ -43,7 +43,6 @@ class Provider(BaseProvider):
         )
 
     def authenticate(self):
-
         if not self.options['auth_token']:
             auth_response = self._auth_request('POST', '/tokens', {
                 'auth': {
@@ -72,7 +71,13 @@ class Provider(BaseProvider):
         data = {'records': [{'type': type, 'name': self._full_name(name), 'data': content}]}
         if self.options.get('ttl'):
             data['records'][0]['ttl'] = self.options.get('ttl')
-        payload = self._post_and_wait('/domains/{0}/records'.format(self.domain_id), data)
+
+        try:
+            payload = self._post_and_wait('/domains/{0}/records'.format(self.domain_id), data)
+        except Exception as e:
+            if str(e).startswith('Record is a duplicate of another record'):
+                return self.update_record(None, type, name, content)
+            raise e
 
         success = len(payload['records']) > 0
         logger.debug('create_record: %s', success)
@@ -82,33 +87,33 @@ class Provider(BaseProvider):
     # type, name and content are used to filter records.
     # If possible filter during the query, otherwise filter after response is received.
     def list_records(self, type=None, name=None, content=None):
-        filter = {'per_page': 100}
+        params = {'per_page': 100}
         if type:
-            filter['type'] = type
+            params['type'] = type
         if name:
-            filter['name'] = self._full_name(name)
+            params['name'] = self._full_name(name)
+        # Sending the data filter to the Rackspace DNS API results in a 503 error
+        # if content:
+        #     params['data'] = content
+
+        payload = self._get('/domains/{0}/records'.format(self.domain_id), params)
+
+        records = list(payload['records'])
         if content:
-            filter['content'] = content
-
-        payload = self._get('/domains/{0}/records'.format(self.domain_id), filter)
-
-        records = []
-        for record in payload['records']:
-            processed_record = {
-                'type': record['type'],
-                'name': record['name'],
-                'ttl': record['ttl'],
-                'content': record['data'],
-                'id': record['id']
-            }
-            records.append(processed_record)
+            records = [record for record in records if record['data'] == content]
+        records = [{
+            'type': record['type'],
+            'name': record['name'],
+            'ttl': record['ttl'],
+            'content': record['data'],
+            'id': record['id']
+        } for record in records]
 
         logger.debug('list_records: %s', records)
         return records
 
     # Create or update a record.
     def update_record(self, identifier, type=None, name=None, content=None):
-
         data = {}
         if type:
             data['type'] = type
@@ -118,10 +123,10 @@ class Provider(BaseProvider):
             data['data'] = content
         if self.options.get('ttl'):
             data['ttl'] = self.options.get('ttl')
-        
+
         if identifier is None:
-            records = self.list_records(type, name, content)
-            if not records[0]:
+            records = self.list_records(type, name)
+            if len(records) < 1:
                 raise Exception('Unable to find record to modify: ' + name)
             identifier = records[0]['id']
 
@@ -134,14 +139,19 @@ class Provider(BaseProvider):
     # Delete an existing record.
     # If record does not exist, do nothing.
     def delete_record(self, identifier=None, type=None, name=None, content=None):
+        delete_record_id = []
         if not identifier:
             records = self.list_records(type, name, content)
-            logger.debug("records: %s", records)
-            if len(records) == 1:
-                identifier = records[0]['id']
-            else:
-                raise Exception('Record identifier could not be found.')
-        payload = self._delete_and_wait('/domains/{0}/records/{1}'.format(self.domain_id, identifier))
+            delete_record_id = [record['id'] for record in records]
+        else:
+            delete_record_id.append(identifier)
+
+        logger.debug('delete_records: %s', delete_record_id)
+
+        for record_id in delete_record_id:
+            payload = self._delete_and_wait(
+                '/domains/{0}/records/{1}'.format(self.domain_id, record_id)
+            )
 
         # If it didn't raise from the http status code, then we're good
         success = True
